package com.ruoyi.web.controller.qdtl;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.qdtl.domain.TlInspectionDeviceTrail;
import com.ruoyi.qdtl.service.ITlInspectionDeviceTrailService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 设备轨迹Controller
 *
 * @author ruoyi
 * @date 2022-03-12
 */
@RestController
@RequestMapping("/qdtl/trail")
public class TlInspectionDeviceTrailController extends BaseController {
    @Autowired
    private ITlInspectionDeviceTrailService tlInspectionDeviceTrailService;

    /**
     * 查询设备轨迹列表
     */
    @PreAuthorize("@ss.hasPermi('qdtl:trail:list')")
    @GetMapping("/list")
    public TableDataInfo list(TlInspectionDeviceTrail tlInspectionDeviceTrail) {
        startPage();
        List<TlInspectionDeviceTrail> list = tlInspectionDeviceTrailService.selectTlInspectionDeviceTrailList(tlInspectionDeviceTrail);
        return getDataTable(list);
    }

    /**
     * 导出设备轨迹列表
     */
    @PreAuthorize("@ss.hasPermi('qdtl:trail:export')")
    @Log(title = "设备轨迹", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TlInspectionDeviceTrail tlInspectionDeviceTrail) {
        List<TlInspectionDeviceTrail> list = tlInspectionDeviceTrailService.selectTlInspectionDeviceTrailList(tlInspectionDeviceTrail);
        ExcelUtil<TlInspectionDeviceTrail> util = new ExcelUtil<TlInspectionDeviceTrail>(TlInspectionDeviceTrail.class);
        util.exportExcel(response, list, "设备轨迹数据");
    }

    /**
     * 获取设备轨迹详细信息
     */
    @PreAuthorize("@ss.hasPermi('qdtl:trail:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return AjaxResult.success(tlInspectionDeviceTrailService.selectTlInspectionDeviceTrailById(id));
    }

    /**
     * 新增设备轨迹
     */
    @PreAuthorize("@ss.hasPermi('qdtl:trail:add')")
    @Log(title = "设备轨迹", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TlInspectionDeviceTrail tlInspectionDeviceTrail) {
        return toAjax(tlInspectionDeviceTrailService.insertTlInspectionDeviceTrail(tlInspectionDeviceTrail));
    }

    /**
     * 修改设备轨迹
     */
    @PreAuthorize("@ss.hasPermi('qdtl:trail:edit')")
    @Log(title = "设备轨迹", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TlInspectionDeviceTrail tlInspectionDeviceTrail) {
        return toAjax(tlInspectionDeviceTrailService.updateTlInspectionDeviceTrail(tlInspectionDeviceTrail));
    }

    /**
     * 删除设备轨迹
     */
    @PreAuthorize("@ss.hasPermi('qdtl:trail:remove')")
    @Log(title = "设备轨迹", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tlInspectionDeviceTrailService.deleteTlInspectionDeviceTrailByIds(ids));
    }
}
